#
# spec file for package libva
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#

%if 0%{?suse_version} < 1320
%bcond_with wayland
%else
%bcond_without wayland
%endif

Name:           libva
Version:        1.5.0
Release:        1.2
Summary:        Video Acceleration (VA) API for Linux
License:        MIT
Group:          System/Libraries
Url:            http://freedesktop.org/wiki/Software/vaapi
Source0:        http://www.freedesktop.org/software/vaapi/releases/libva/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  Mesa-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xv)
%if %{with wayland}
BuildRequires:  pkgconfig(wayland-client) >= 1.0.0
%endif

%description
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

%package -n libva1
Summary:        Video Acceleration (VA) API for Linux
Group:          System/Libraries
Recommends:     vaapi-dummy-driver

%description -n libva1
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

This is the core runtime library

%package -n libva-drm1
Summary:        Video Acceleration (VA) API for Linux -- VA/DRM Backend
Group:          System/Libraries
Supplements:    libva1

%description -n libva-drm1
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

This is the VA/DRM runtime library

%package -n libva-egl1
Summary:        Video Acceleration (VA) API for Linux -- VA/EGL Backend
Group:          System/Libraries
Supplements:    libva1

%description -n libva-egl1
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

This is the VA/EGL runtime library

%package -n libva-x11-1
Summary:        Video Acceleration (VA) API for Linux -- VA/X11 Backend
Group:          System/Libraries
Supplements:    libva1

%description -n libva-x11-1
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

This is the VA/X11 runtime library

%package -n libva-glx1
Summary:        Video Acceleration (VA) API for Linux -- VA/GLX Backend
Group:          System/Libraries
Supplements:    libva1

%description -n libva-glx1
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

This is the VA/GLX runtime library

%if %{with wayland}
%package -n libva-wayland1
Summary:        Video Acceleration (VA) API for Linux -- Wayland support
Group:          System/Libraries

%description -n libva-wayland1
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.
%endif

%package devel
Summary:        Video Acceleration (VA) API for Linux -- development files
Group:          Development/Languages/C and C++
Requires:       libva-drm1 = %{version}
Requires:       libva-egl1 = %{version}
Requires:       libva-glx1 = %{version}
%if %{with wayland}
Requires:       libva-wayland1 = %{version}
%endif
Requires:       libva-x11-1 = %{version}
Requires:       libva1 = %{version}
Requires:       pkgconfig(gl)
Requires:       pkgconfig(libdrm)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xfixes)

%description devel
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

This package provides the development environment for libva.

%package -n vaapi-tools
Summary:        Video Acceleration (VA) API for Linux
Group:          System/Libraries

%description -n vaapi-tools
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

This is a set of tools around vaapi livrary.

%if %{with wayland}
%package -n vaapi-wayland-tools
Summary:        Video Acceleration (VA) API for Linux - Wayland support
Group:          System/Libraries

%description -n vaapi-wayland-tools
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.
%endif

%package -n vaapi-dummy-driver
Summary:        Video Acceleration (VA) API for Linux
Group:          System/Libraries

%description -n vaapi-dummy-driver
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

This contains the dummy driver.

%prep
%setup -q 

%build
[ -d m4 ]  || mkdir m4
autoreconf -v --install
%configure --enable-dummy-driver \
           --enable-glx \
           --enable-egl \
           --with-drivers-path=%{_libdir}/dri \
%if %{with wayland}
           --enable-wayland
%else
           --disable-wayland
%endif
make %{?_smp_mflags}

%install
%makeinstall
find %{buildroot} -name '*.la' -delete -print

%post -n libva1 -p /sbin/ldconfig

%postun -n libva1 -p /sbin/ldconfig

%post -n libva-drm1 -p /sbin/ldconfig

%postun -n libva-drm1 -p /sbin/ldconfig

%post -n libva-egl1 -p /sbin/ldconfig

%postun -n libva-egl1 -p /sbin/ldconfig

%post -n libva-glx1 -p /sbin/ldconfig

%postun -n libva-glx1 -p /sbin/ldconfig

%post -n libva-x11-1 -p /sbin/ldconfig

%postun -n libva-x11-1 -p /sbin/ldconfig

%files -n vaapi-tools
%defattr(-,root,root,-)
%{_bindir}/vainfo
%{_bindir}/avcenc
%{_bindir}/h264encode
%{_bindir}/mpeg2vaenc
%{_bindir}/mpeg2vldemo
%{_bindir}/putsurface
%{_bindir}/loadjpeg
%{_bindir}/jpegenc

%if %{with wayland}
%files -n vaapi-wayland-tools
%defattr(-,root,root)
%{_bindir}/putsurface_wayland

%files -n libva-wayland1
%defattr(-, root, root)
%{_libdir}/libva-wayland.so.*
%endif

%files -n vaapi-dummy-driver
%defattr(-,root,root,-)
%dir %{_libdir}/dri
%{_libdir}/dri/dummy_drv_video.so

%files -n libva1
%defattr(-, root, root)
%{_libdir}/libva.so.*
%{_libdir}/libva-tpi.so.*

%files -n libva-x11-1
%defattr(-, root, root)
%{_libdir}/libva-x11.so.*

%files -n libva-glx1
%defattr(-, root, root)
%{_libdir}/libva-glx.so.*

%files -n libva-egl1
%defattr(-, root, root)
%{_libdir}/libva-egl.so.*

%files -n libva-drm1
%defattr(-, root, root)
%{_libdir}/libva-drm.so.*

%files devel
%defattr(-,root,root,-)
%{_libdir}/libva.so
%{_libdir}/libva-tpi.so
%{_libdir}/libva-x11.so
%{_libdir}/libva-glx.so
%{_libdir}/libva-egl.so
%{_libdir}/libva-drm.so
%if %{with wayland}
%{_libdir}/libva-wayland.so
%endif
%{_includedir}/va
%{_libdir}/pkgconfig/libva*.pc

%changelog
* Sun Feb  8 2015 zaitor@opensuse.org
- Update to version 1.5.0:
  + API:
  - Add support for HEVC decoding.
  - Extend JPEG encoding data structures and add configuration
    attribute for JPEG encoding.
  + Add a unit test for JPEG encoding.
  + Add support for HEVC decoding and JPEG encoding in VA trace
    utility.
  + Fix out of tree builds.
  + VA/X11: fix BadDrawable issue when calling vaTerminate() after
    the pixmaps have been destroyed.
* Thu Oct 30 2014 sndirsch@suse.com
- added baselibs.conf as source to specfile in order to make factory
  happy
* Mon Oct 27 2014 sndirsch@suse.com
- update to version 1.4.1; most important features/changes since
  release 1.2.1:
  * API: add support for VP8 encoding
  * API: drop VAEntrypointMax enumeration
  * API: add STE filter to the VPP pipeline
  * API: add H.264 MVC profiles for decoding and encoding
  * API: add buffer export interfaces for interop with 3rdparty APIs (EGL, OCL)
  * API: add suppor for encoder quality level
  * API: add attribute usage hint flag
  * Enhancement for VA trace utility
  * Add support for DRM Render-Nodes (Andrey Larionov)
- removed obsolete patch libva-fix-rpmlint-error-no-return-in-non-void.patch
* Fri Sep 27 2013 dimstar@opensuse.org
- Introduce bcond_with wayland to easily control if the wayland
  support is to be built:
  + On openSUSE 13.1+ defaults to true
  + Create new subpackage vaapi-wayland-tools and libva-wayland1,
    containing the respective wayland support of libva.
  + BuilkdRequire pkgconfig(wayland-client).
  + Pass --enable/--disable-wayland to configure as appropriate.
* Wed Jul 10 2013 hrvoje.senjan@gmail.com
- updated to version 1.2.1:
  * fixed namespace issue with one of the new tools introduced as
    mpeg2enc. fdo#66221
  * API: new H.264 encoding API for Baseline, Main and High profiles
  * API: add support for MPEG-2 encoding
  * API: add video processing interfaces
  * API: add vaQuerySurfaceAttributes() to query surface attributes
    supported by the underlying drivers.
  * API: new version of vaCreateSurfaces(), the old version of
    vaCreateSurfaces() is still supported if including <va/va_compat.h>
  * API: add new surface attributes to enable VA surface creation
    from external buffer
  * API: add new RT formats and fourcc codes
  * Refine VA trace utility
  * Refine H.264 encoding test cases {avcenc, h264enc}
  * A new test case for MPEG-2 encoding
  * A lot of bug fixes
* Tue Mar 19 2013 kkhere.geo@gmail.com
- Version 1.1.1 - 18.Mar.2013
  This minor version brings the following changes:
  * Support wayland 1.0 protocol (Rob Bradford)
  * Automake 1.13 fixups (Armin K)
* Tue Nov 13 2012 guillaume@opensuse.org
- Remove Exclusive arch on x86*
* Thu Oct 18 2012 kkhere.geo@gmail.com
- fix rpmlint error no-return-in-nonvoid-function
* Thu Oct 18 2012 kkhere.geo@gmail.com
- packaging va backends seperately
* Thu Oct 18 2012 kkhere.geo@gmail.com
- previous bump to 1.1.0 was reverted upstream
- Version 1.1.0 - 04.Oct.2012
  * API: add Wayland support
  * API: add raw DRM support for headless pipelines
  * Fix generic VA/GLX implementation for newer cluttersink versions
  * Fix threading issues in VA objects reference code (+Krzysztof Kotlenga)
  * Fix build on Android Ice Cream Sandwich (+Haitao Huang, Daniel Charles)
* Tue May 29 2012 kkhere.geo@gmail.com
- get osc service localrun download_files to run
* Tue May 29 2012 tiwai@suse.de
- updated to version 1.1.0:
  * support of JPEG decoding
  * New hooks to create/free native pixmap
  * VA/EGL interfaces
  * Remove legacy DRI support
* Fri May 25 2012 kkhere.geo@gmail.com
- Remove nonexisting subpackage from baselibs.conf
* Wed May 23 2012 kkhere.geo@gmail.com
- Rename subpackage vaapi-drivers -> vaapi-dummy-driver
  since dummy is the only driver this package contains.
- Let the library recommend the dummy driver in case no other
  is present
* Tue May 22 2012 crrodriguez@opensuse.org
- Remove intel-driver, it has been packaged separately
  with proper hardware "Supplements" so it gets installed
  only when needed.
- Fix -devel package requires, otherwise dependant packages
  fail with missing headers wanted by files in /usr/include/va.
* Fri Apr 13 2012 kkhere.geo@gmail.com
- update intel driver to version 1.0.17
  Version 1.0.17 - 02.Apr.2012
  * Add support for IMC1/IMC3 surface formats
  * Fix rendering of interlaced surfaces
  * Fix MPEG-2 decoding of interlaced streams (SNB, IVB)
  * Fix H.264 weighted prediction indicator (SNB)
  * Fix and simplify calculation of H.264 macroblock bit offset (ILK, SNB, IVB)
  Version 1.0.16 - 14.Feb.2012
  * Fix VC-1 bitplane buffer size (SNB, IVB)
  * Fix VC-1 motion vector modes for Ivy Bridge
  * Fix MFX_QM_STATE for H.264 flat scaling lists (IVB)
  * Fix and simplify AVC_REF_IDX_STATE setup (ILK, SNB, IVB)
  * Fix memory leak of encoder buffers
  * Fix check for internal VA surface format prior to rendering
  * Add support for B43 chipset (Alexander Inyukhin)
* Wed Mar 21 2012 jengelh@medozas.de
- Remove redundant sections, compress filelist
- Enable parallel build
- Use pkgconfig symbols for deps
* Mon Feb 27 2012 dmueller@suse.de
- exclude from build on ARM
* Tue Feb 14 2012 sndirsch@suse.com
- Update package BuildRequires to use pkgconfig symbols
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Nov  9 2011 kkhere.geo@gmail.com
- new version 1.0.15
  * API: make {Top,Bottom}FieldOrderCnt signed (Yi Wang)
  * Add auto-generated Debian packaging
  * Refine VA trace & VA fool utilities
  * Move i965 driver to a specific repository (vaapi/intel-driver)
  * Fix DSO link issue in tests
  * Fix fglrx driver name detection
  * Fix API vs. DSO vs. package versioning
- intel-driver has been split from the library, use separate tarball
- split the drivers into a separate package
* Tue Aug  9 2011 kkhere.geo@gmail.com
- new version 1.0.14
  no NEWS released; changelog in git http://cgit.freedesktop.org/libva/
* Tue May 31 2011 kkhere.geo@gmail.com
- new version 1.0.13
  * cleans up licensing issue
  * IvyBrigde video decoding support
  * thread safety
  * Encoding support in SandyBridge
* Fri Apr  1 2011 kkhere.geo@gmail.com
- new version 1.0.12
* Mon Mar 28 2011 kkhere.geo@gmail.com
- new version 1.0.11
  * obsoletes patch
  - i965_dri_video: don't try to render an invalid surface
* Thu Mar  3 2011 kkhere.geo@gmail.com
- patch: i965_dri_video: don't try to render an invalid surface
* Tue Feb 15 2011 kkhere.geo@gmail.com
- new version 1.0.10
* Mon Jan 10 2011 kkhere.geo@gmail.com
- new version 1.0.7
- support IA44 AI44 subpicture format in sandybridge
* Sun Dec 19 2010 lnussel@suse.de
- new version 1.0.6
* Fri Nov  5 2010 kkhere.geo@gmail.com
- update to version 1.0.6
* Thu Sep 30 2010 kkhere.geo@gmail.com
- update to version 1.0.5
  * add scaling flags for vaPutSurface()
  * i965_drv_video: add video processing kernels
  * i965_drv_video: deinterlacing & scaling
* Thu Sep  9 2010 kkhere.geo@gmail.com
- update to version 1.0.4
* Tue Jun  8 2010 dimstar@opensuse.org
- Split the library in libva1, the tools in vaapi-tools and the
  development in libva-devel. Both libraries can live in the same
  package as per policy: they are kept in sync with their soNUM.
* Mon Jun  7 2010 dominique-vlc.suse@leuenberger.net
- Initial package for VideoLAN repository, libva 1.0.1
